@@ -575,7 +575,7 @@ class Snaplib:
             # split for testing
             if feature_type_target == 'object' and last_item < 2:
                 X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.5, random_state=0)
-            if feature_type_target == 'object' and last_item < 3:
+            elif feature_type_target == 'object' and last_item < 3:
                 X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.5, random_state=0, stratify=y)
             elif feature_type_target == 'object' and last_item < 5:
                 X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.25, random_state=0, stratify=y)
@@ -583,6 +583,11 @@ class Snaplib:
                 X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.2, random_state=0, stratify=y)
             else:
                 X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.2, random_state=0)
+
+
+
+
+
             # else:
             # df_conctd = pd.concat([X, pd.Series(y, name=target_now)], axis=1)
             # X_train, X_test, y_train, y_test = self.train_test_split_balanced(df_conctd, target_now, test_size=0.2, random_state=0, research_iter=0)
